#!/bin/bash

## SAMPLE. Change the NFS mount points to match your environment


## Internal Variables, do not modify
export TOOLKIT=/TOOLKIT
export NFS_MAIN=/mnt/nfs
export HWDISC_FILE=/TOOLKIT/data_files/hwdisc.dat
export SERVERNAME=
export BOOTDEVNODE=

clear
echo "*** Capturing Configuration ***"


## SAMPLE. Change this to match your NFS server IP/path

echo "Mounting NFS share"
mkdir ${NFS_MAIN}
mount -t nfs 10.0.0.1:/TOOLKIT ${NFS_MAIN} -o ro,nolock
if [ $? != 0 ]; then
	echo "Unable to mount NFS share, make sure you updated the $0 script with the location of your NFS server."
	exec /bin/bash
fi

echo "Copying over toolkit scripts and utilites from NFS share"
cd ${TOOLKIT}
cp -a ${NFS_MAIN}/scripts/* ${TOOLKIT}
cp -a ${NFS_MAIN}/utilities/* ${TOOLKIT}
mkdir -p ${TOOLKIT}/data_files/

echo ""
echo "Loading storage drivers for hardware"
./load_modules.sh


echo ""
echo "Pausing to allow drivers to finish loading"
sleep 5
echo ""

cd ${TOOLKIT}

## rerun hardware discovery 
./hwdisc3 -f${HWDISC_FILE}
echo "Hardware Discovery saved to ${HWDISC_FILE}"


## use hwquery to fetch the SystemName from hardware discovery file. ( extra " " are required ) 
export "`./hwquery ${HWDISC_FILE} allboards.xml SERVERNAME=SystemName`";

echo "Server Type: ${SERVERNAME}"

./conrep -s -fdata_files/conrep.dat
if [ $? = 0 ] ; then
	echo "System Configuration saved to ${TOOLKIT}/data_files/conrep.dat"
fi

./ifhw ${HWDISC_FILE} allboards.xml "PCI:Smart Array" 2> /dev/null
if [ $? = 0 ] ; then
	cd ${TOOLKIT}/cpqacuxe
	./cpqacuxe -c ../data_files/cpqacuxe.dat
	if [ $? = 0 ] ; then
		echo "Array Configuration saved to ${TOOLKIT}/data_files/cpqacuxe.dat"
	fi
else
	echo "No Smart Array detected, no ACU Configuration captured."
fi

cd ${TOOLKIT}

./ifhw ${HWDISC_FILE} allboards.xml "PCI:Integrated Lights-Out" 2> /dev/null
if [ $? = 0 ] ; then
	insmod /opt/compaq/cpqci/driver/cpqci.ko
	./hponcfg -w data_files/hponcfg.dat 
	if [ $? = 0 ] ; then
		echo "Integrated Lights-Out Configuration Report saved to ${TOOLKIT}/data_files/hponcfg.dat"
		echo " - this is not a RIBCL configuration script"
	fi
fi

echo ""
echo "${TOOLKIT} is a ramdisk, copy these files elsewhere to keep them."
echo "Press CTRL-D or type exit to end the session and reboot."
/bin/bash

${TOOLKIT}/reboot
